@@ -1,12 +1,12 @@
 use strict;
 use warnings;
-
-package B::Hooks::OP::Check;
+package B::Hooks::OP::Check; # git description: 0.19-4-gb3d8460
+# ABSTRACT: Wrap OP check callbacks
 
 require 5.008001;
 use parent qw/DynaLoader/;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 sub dl_load_flags { 0x01 }
 
@@ -16,10 +16,18 @@ __PACKAGE__->bootstrap($VERSION);
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 B::Hooks::OP::Check - Wrap OP check callbacks
 
+=head1 VERSION
+
+version 0.20
+
 =head1 SYNOPSIS
 
     # include "hook_op_check.h"
@@ -43,7 +51,7 @@ B::Hooks::OP::Check - Wrap OP check callbacks
 
 =head1 DESCRIPTION
 
-This module provides a c api for XS modules to hook into the callbacks of
+This module provides a C API for XS modules to hook into the callbacks of
 C<PL_check>.
 
 L<ExtUtils::Depends> is used to export all functions for other XS modules to
@@ -57,6 +65,8 @@ use. Include the following in your Makefile.PL:
 
 Your XS module can now include C<hook_op_check.h>.
 
+=for stopwords cb
+
 =head1 TYPES
 
 =head2 typedef OP *(*hook_op_check_cb) (pTHX_ OP *, void *);
@@ -78,18 +88,42 @@ on.
 
 =head2 void *hook_op_check_remove (opcode type, hook_op_check_id id)
 
-Remove the callback identified by C<id>. Returns the userdata the callback had.
+Remove the callback identified by C<id>. Returns the user_data that the callback had.
+
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-Hooks-OP-Check>
+(or L<bug-B-Hooks-OP-Check@rt.cpan.org|mailto:bug-B-Hooks-OP-Check@rt.cpan.org>).
 
 =head1 AUTHOR
 
-Florian Ragwitz E<lt>rafl@debian.orgE<gt>
+Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
 
-Copyright (c) 2008 Florian Ragwitz
+=for stopwords Karen Etheridge Zefram Alexandr Ciornii
 
-This module is free software.
+=over 4
 
-You may distribute this code under the same terms as Perl itself.
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Zefram <zefram@fysh.org>
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
